const { execSync } = require('child_process')
const pkg = require('./package.json')
const args = process.argv.slice(2)
const options = {}

for (let i = 0; i < args.length - 1; i += 2) {
    const option = args[i].replace('--', '')
    options[option] = args[i + 1]
}

function shouldPublish() {
    const branch = options.buildBranch
    console.log('Found git ref: ' + branch)
    
    if (pkg.private) {
        console.warn('Package marked private, refusing to publish')
        return false
    }

    if (branch.indexOf('/tags/') === -1) {
        console.warn('Not a tag, refusing to publish')
        return false
    }

    const [, taggedVersion] = branch.match('/tags/(.+)$')
    const packageVersion = pkg.version

    if (packageVersion !== taggedVersion.replace(/^v/, '')) {
        console.warn('Package version and git tag are mismatched, refusing to publish')
        return false
    }

    try {
        const existingVersion = execSync('npm view ' + pkg.name + '@' + pkg.version + ' version', { encoding: 'utf8' })

        if (existingVersion.trim().length) {
            console.warn('Package version ' + existingVersion + ' already exists, refusing to publish')
            return false
        }
    } catch (error) {
        console.warn(error)
    }

    return true
}

if (shouldPublish()) {
    console.log('Publishing to NPM')
    execSync('npm config set "//registry.npmjs.org/:_authToken" "' + options.authToken + '"')
    execSync('npm publish --access public', { stdio: 'inherit' })
    execSync('npm config delete "//registry.npmjs.org/:_authToken"')
}